@@ -2,8 +2,10 @@
 插件相关配置
 """
 
+from typing import Dict
 from pydantic import BaseModel, Extra
 
 
 class Config(BaseModel, extra=Extra.ignore):
-    update_time: int = 720  # 更新时间间隔 [分钟]
\ No newline at end of file
+    update_time: int = 720  # 更新时间间隔 [分钟]
+    # proxies: str = ""
\ No newline at end of file
